@@ -1,5 +1,5 @@
 package ZMQ::FFI::ZMQ2::Context;
-$ZMQ::FFI::ZMQ2::Context::VERSION = '0.16';
+$ZMQ::FFI::ZMQ2::Context::VERSION = '0.17';
 use Moo;
 use namespace::autoclean;
 
@@ -8,6 +8,7 @@ use Carp;
 use Try::Tiny;
 
 use ZMQ::FFI::ZMQ2::Socket;
+use ZMQ::FFI::Constants qw(ZMQ_STREAMER);
 
 extends qw(ZMQ::FFI::ContextBase);
 
@@ -66,6 +67,18 @@ sub socket {
     );
 }
 
+# zeromq v2 does not provide zmq_proxy; implemented here in terms of zmq_device
+sub proxy {
+    my ($self, $front, $back, $capture) = @_;
+
+    croak "zeromq v2 does not support a capture socket" if defined $capture;
+
+    $self->check_error(
+        'zmq_device',
+        $self->_ffi->{zmq_device}->(ZMQ_STREAMER, $front->_socket, $back->_socket)
+    );
+}
+
 sub destroy {
     my $self = shift;
 
@@ -89,6 +102,14 @@ sub _init_ffi {
         FFI::Raw::int  # num threads
     );
 
+    $ffi->{zmq_device} = FFI::Raw->new(
+        $soname => 'zmq_device',
+        FFI::Raw::int, # error code
+        FFI::Raw::int, # type
+        FFI::Raw::ptr, # frontend
+        FFI::Raw::ptr, # backend
+    );
+
     $ffi->{zmq_term} = FFI::Raw->new(
         $soname => 'zmq_term',
         FFI::Raw::int, # retval
@@ -117,7 +138,7 @@ ZMQ::FFI::ZMQ2::Context
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 AUTHOR
 
